@@ -11,7 +11,7 @@
 # b) the "Artistic License".
 package ClamTk::App;
 
-use strict;
+# use strict;
 # use warnings FATAL => 'all';
 $| = 1;
 
@@ -24,7 +24,7 @@ use Locale::gettext;
 
 sub get_TK_version {
     # Stick with %.2f format - 4.50 vice 4.5
-    return '4.37';
+    return '4.38';
 }
 
 sub get_path {
