@@ -11,7 +11,7 @@
 # b) the "Artistic License".
 package ClamTk::GUI;
 
-use strict;
+# use strict;
 # use warnings;
 # Can't use FATAL with warnings here;
 # chokes on the readline if the stop button is hit.
@@ -552,15 +552,15 @@ sub start_gui {
             }
         } else {
             my $pos = 0;
+            my @send;
             for my $f (@ARGV) {
                 $f = abs_path($f);
-                if ( $f =~ m#^/(proc|sys|dev)#
-                    or not -r $f ) {
-                    splice( @ARGV, $pos, 1 );
-                    $pos++;
-                }
+                next if ( $f =~ m#^/(proc|sys|dev)#
+                    or not -r $f );
+                push( @send, $f );
             }
-            ClamTk::GUI->getfile( 'cmd-scan', @ARGV );
+            #ClamTk::GUI->getfile( 'cmd-scan', @ARGV );
+            ClamTk::GUI->getfile( 'cmd-scan', @send );
         }
     } else {
         update_status_frame();
@@ -863,7 +863,7 @@ sub getfile {
     # specific path - kmail (e.g.) is somewhere under $HOME/.kde/blah/foo/...
     my @maildirs = qw(
         .thunderbird	.mozilla-thunderbird
-        .evolution	Mail	kmail
+        Mail	kmail
         );
     for my $mailbox (@maildirs) {
         $directive .= " --exclude-dir=$mailbox";
@@ -978,15 +978,14 @@ sub getfile {
             return;
         }
     } elsif ( $option eq 'cmd-scan' ) {
-        if ( -d $cmd_input[0] ) {
+        if ( $cmd_input[0] && -d $cmd_input[0] ) {
             please_wait();
             $window->queue_draw;
             Gtk2->main_iteration while ( Gtk2->events_pending );
             @files = $rule->in( $cmd_input[0] );
             push( @scans, $cmd_input[0] );
             if ( !$prefs{Recursive} ) {
-                $directive .= ' --max-dir-recursion=1'
-                    if ( $option ne 'recur' );
+                $directive .= ' --max-dir-recursion=1';
             } elsif ( $prefs{Recursive} ) {
                 $directive .= ' --recursive';
             }
@@ -995,7 +994,7 @@ sub getfile {
             $window->queue_draw;
             Gtk2->main_iteration while ( Gtk2->events_pending );
             for (@cmd_input) {
-                push( @scans, $_ ) if ( -f $_ );
+                push( @scans, $_ );    # if ( -f $_ );
             }
             $directive .= ' --max-dir-recursion=1';
             @files = @scans;
@@ -1291,10 +1290,19 @@ sub clean_up {
     # Clear the progressbar
     $pb->set_fraction(1.0);
 
+    # No files scanned?
+    if ( $num_scanned == 0 ) {
+        $last_scan_bar->set_markup( "<span background = '#FFFFC8'>"
+                . gettext('No files were scanned.')
+                . "</span>" );
+        $last_scan_bar->show_all();
+    } else {
+        $last_scan_bar->set_text('');
+        $last_scan_bar->hide();
+    }
+
     # ...and remove the text
     $pb->set_text("");
-    $last_scan_bar->set_text('');
-    $last_scan_bar->hide();
 
     my $db_total = ClamTk::App->get_num_sigs();
     my $REPORT;    # filehandle for histories log
@@ -2398,6 +2406,7 @@ sub get_md5 {
 
 sub about {
     my $about = Gtk2::AboutDialog->new;
+	$about->set_program_name( 'ClamTk' );
     $about->set_authors("Dave M, 2004-2012\ndave.nerd <at> gmail.com");
     $about->set_version( ClamTk::App->get_TK_version() );
     my $contributors = 'Please see http://clamtk.sf.net/credits.html';
