@@ -11,7 +11,7 @@
 # b) the "Artistic License".
 package ClamTk::Prefs;
 
-use strict;
+# use strict;
 # use warnings FATAL => 'all';
 $| = 1;
 
@@ -158,14 +158,16 @@ sub custom_prefs {
         qw{SaveToLog ScanHidden SizeLimit
         Thorough Recursive Mounted}
         ) {
+        # off by default
         if ( !exists $pkg{$o} ) {
-            $pkg{$o} = 0;    # off by default
+            $pkg{$o} = 0;
         }
     }
 
     for my $p (qw{OpenDNS AVCheck GUICheck TruncateLog}) {
+        # on by default
         if ( !exists $pkg{$p} ) {
-            $pkg{$p} = 1;    # on by default
+            $pkg{$p} = 1;
         }
     }
     write_all(%pkg);
