@@ -11,7 +11,7 @@
 # b) the "Artistic License".
 package ClamTk::Results;
 
-use strict;
+# use strict;
 # use warnings FATAL => 'all';
 $| = 1;
 
@@ -37,7 +37,7 @@ my $hash;
 # We have to avoid parsing mail for now:
 # http://clamtk.sourceforge.net/faq.html#inbox
 my $maildirs = join( '|',
-    '.thunderbird', '.mozilla-thunderbird', '.evolution',
+    '.thunderbird', '.mozilla-thunderbird', 'evolution(?!/tmp)',
     'Mail',         'kmail',                "\.pst" );
 
 sub display {
@@ -138,7 +138,7 @@ sub display {
             $quar_pop->signal_connect(
                 activate => sub {
                     for my $t (@sel) {
-                        next if ( $hash->{$t}->{name} =~ /$maildirs/ );
+                        next if ( $hash->{$t}->{name} =~ m#$maildirs# );
                         next if ( -d $hash->{$t}->{name} );
                         main_confirm( $t, 'q' );
                     }
@@ -157,7 +157,7 @@ sub display {
             $delete_pop->signal_connect(
                 activate => sub {
                     for my $u (@sel) {
-                        next if ( $hash->{$u}->{name} =~ /$maildirs/ );
+                        next if ( $hash->{$u}->{name} =~ m#$maildirs# );
                         next if ( -d $hash->{$u}->{name} );
                         main_confirm( $u, 'd' );
                     }
@@ -228,7 +228,7 @@ sub display {
         clicked => sub {
             my @sel = $slist->get_selected_indices;
             for my $t (@sel) {
-                next if ( $hash->{$t}->{name} =~ /$maildirs/ );
+                next if ( $hash->{$t}->{name} =~ m#$maildirs# );
                 next if ( -d $hash->{$t}->{name} );
                 main_confirm( $t, 'q' );
             }
@@ -241,7 +241,7 @@ sub display {
         clicked => sub {
             my @sel = $slist->get_selected_indices;
             for my $u (@sel) {
-                next if ( $hash->{$u}->{name} =~ /$maildirs/ );
+                next if ( $hash->{$u}->{name} =~ m#$maildirs# );
                 next if ( -d $hash->{$u}->{name} );
                 main_confirm( $u, 'd' );
             }
