@@ -14,7 +14,7 @@ package ClamTk::Schedule;
 # I haven't found a cross-distro Perl module for
 # scheduling, so we have call crontab as a system command.
 
-use strict;
+# use strict;
 # use warnings FATAL => 'all';
 $| = 1;
 
@@ -379,7 +379,7 @@ sub apply_scan {
     # Ignore mail directories until we can parse stuff
     for my $not_parse (
         qw| .thunderbird	.mozilla-thunderbird
-        .evolution	Mail	kmail |
+        .evolution 	Mail	kmail |
         ) {
         $full_cmd .= ' --exclude-dir=' . $not_parse;
     }
@@ -394,7 +394,7 @@ sub apply_scan {
     $full_cmd .= ( $home_b->get_active ) ? $home : $root;
 
     # Add the (ugly) logging
-    $full_cmd .= ' --log=$HOME/.clamtk/history/$(date +\%b-\%d-\%Y).log'
+    $full_cmd .= ' --log="$HOME/.clamtk/history/$(date +\%b-\%d-\%Y).log"'
         . ' 2>/dev/null';
 
     open( $T, '>>:encoding(UTF-8)', $tmp_file ) or do {
