@@ -11,7 +11,7 @@
 # b) the "Artistic License".
 package ClamTk::Update;
 
-use strict;
+# use strict;
 # use warnings FATAL => 'all';
 $| = 1;
 
